﻿/*
 Copyright (c) 2011 Seth Juarez

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/

using System;
using System.IO;
using ml.Supervised;
using ml.Tests.Model;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace ml.Tests
{
    [TestClass]
    public class LinearRegressionTests
    {
        [TestInitialize]
        public void InitializeTest()
        {
            // we need to ensure the file exists before we 
            // call, so we will call Test_Perceptron_Save first
            Test_Regression_Save();
        }

        [TestMethod]
        public void Test_Main_Regression()
        {
            StudentGrade[] data = StudentGrade.GetData();

            // test point
            StudentGrade s = new StudentGrade { Name = "Seth", Age = 30, Friends = 1, Grade = Grade.F, Tall = false, Nice = false };

            var model = new LinearRegressionModel<StudentGrade>();
            var predictor = model.Generate(data);

            s = predictor.Predict(s);
        }

        [TestMethod]
        public void Test_Regression_Load_Stream()
        {
            string path = Directory.GetCurrentDirectory() + @"\regression_serialize_test.xml";

            // test point
            StudentGrade s = new StudentGrade { Name = "Seth", Age = 30, Friends = 1, Grade = Grade.F, Tall = false, Nice = false };

            var model = new LinearRegressionModel<StudentGrade>();
            using (var stream = File.OpenRead(path))
            {
                var predictor = model.Load(stream);
                predictor.Predict(s);
            }
        }

        [TestMethod]
        public void Test_Regression_Save()
        {
            string path = Directory.GetCurrentDirectory() + @"\regression_serialize_test.xml";

            StudentGrade[] students = StudentGrade.GetData();

            var model = new LinearRegressionModel<StudentGrade>();
            var predictor = model.Generate(students);
            predictor.Save(path);
        }

        [TestMethod]
        public void Test_Regression_Load()
        {
            string path = Directory.GetCurrentDirectory() + @"\regression_serialize_test.xml";

            // test point
            StudentGrade s = new StudentGrade { Name = "Seth", Age = 30, Friends = 1, Grade = Grade.F, Tall = false, Nice = false };

            var model = new LinearRegressionModel<StudentGrade>();
            var predictor = model.Load(path);
            predictor.Predict(s);
        }

    }
}
