﻿/*
 Copyright (c) 2011 Seth Juarez

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/

using System;
using ml.Attributes;
using ml.Tests.Model;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace ml.Tests
{
    [TestClass]
    public class ObjectConverterTests
    {
        [TestMethod]
        public void Student_To_TypeDescription_Test()
        {
            var t = Converter.GetDescription(typeof(Student));
        }

        [TestMethod]
        public void Student_Build_Dictionary_On_Property_Test()
        {
            var p = new StringProperty
            {
                SplitType = StringType.Character,
                Name = "Name",
                Type = typeof(string),
                isMethod = false
            };

            var t = Converter.BuildDictionary<Student>(Student.GetData(), p);

        }

        [TestMethod]
        public void Student_Build_Dictionary_On_Char_Test()
        {
            var p = new StringProperty
            {
                SplitType = StringType.Character,
                Name = "GetName",
                Type = typeof(string),
                isMethod = true
            };

            Student[] s = new Student[] { new Student { Name = "I like to eat a lot of chees in the morning times! At least 8 or nine!" } };
            var t = Converter.BuildDictionary<Student>(Student.GetData(), p);

        }

        [TestMethod]
        public void Student_Build_Dictionary_On_Word_Test()
        {
            var p = new StringProperty
            {
                SplitType = StringType.Word,
                Name = "GetName",
                Type = typeof(string),
                isMethod = true,
                Separator = " "
            };

            Student[] s = new Student[] { new Student { Name = "1.1 I like? to! e#at a lot of cheese in the morning times! At least 8 or 9!" } };
            var t = Converter.BuildDictionary<Student>(s, p);
        }


        [TestMethod]
        public void Build_Dictionary_Into_TypeDesc()
        {
            var data = Student.GetData();
            var typeDesc = Converter.GetDescription(typeof(Student))
                                        .BuildDictionaries<Student>(data);
            
        }

        [TestMethod]
        public void Build_Vector_From_Object()
        {
            var examples = Student.GetData();
            var data = Converter.Convert<Student>(examples);
        }
    }
}
