﻿/*
 Copyright (c) 2011 Seth Juarez

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/

using System;
using System.IO;
using ml.Attributes;
using MachineLearningDemo.Data;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace ml.Tests
{
    [TestClass]
    public class StringFeatureTests
    {
        private string _stopwords;
        private string _stopchars;
        [TestInitialize]
        public void InitializeTest()
        {
            if (!Directory.Exists(@"C:\MLTests"))
                Directory.CreateDirectory(@"C:\MLTests");


            CreateWordFile();
            CreateCharFile();
        }

        private void CreateWordFile()
        {
            _stopwords = @"C:\MLTests\stopwords.txt";
            var stoplist = "a,able,about,across,after,all,almost,also,am,among,an,and,any,are,as,at,be,because,been,but,by,can,cannot,could,dear,did,do,does,either,else,ever,every,for,from,get,got,had,has,have,he,her,hers,him,his,how,however,i,if,in,into,is,it,its,just,least,let,like,likely,may,me,might,most,must,my,neither,no,nor,not,of,off,often,on,only,or,other,our,own,rather,said,say,says,she,should,since,so,some,than,that,the,their,them,then,there,these,they,this,tis,to,too,twas,us,wants,was,we,were,what,when,where,which,while,who,whom,why,will,with,would,yet,you,your";

            if (File.Exists(_stopwords))
                File.Delete(_stopwords);

            using (TextWriter tw = new StreamWriter(_stopwords))
                foreach(var word in stoplist.Split(','))
                    tw.WriteLine(word);
        }

        private void CreateCharFile()
        {
            _stopchars = @"C:\MLTests\stopchars.txt";
            var stoplist = "a,e,i,o,u";

            if (File.Exists(_stopchars))
                File.Delete(_stopchars);

            using (TextWriter tw = new StreamWriter(_stopchars))
                foreach (var word in stoplist.Split(','))
                    tw.WriteLine(word);
        }

        [TestMethod]
        public void Test_String_Feature_Word_Exclusions()
        {
            StringFeatureAttribute attr = new StringFeatureAttribute(StringType.Word, exclusions: _stopwords);
            Assert.IsTrue(attr.Exclusions.Length == 119);
        }

        [TestMethod]
        public void Test_String_Feature_Char_Exclusions()
        {
            StringFeatureAttribute attr = new StringFeatureAttribute(StringType.Character, exclusions: _stopchars);
            Assert.IsTrue(attr.Exclusions.Length == 5);
        }

        [TestMethod]
        public void Test_Load_Feed_Dictionary_With_Exclusion()
        {
            var examples = Feed.GetData();
            var desc = Converter.GetDescription(typeof(Feed)).BuildDictionaries<Feed>(examples);
        }
    }
}
