﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using ml.Attributes;
using ml.Math;
using ml.Metrics;
using ml.Unsupervised.Linkers;
using System.Threading.Tasks;

namespace ml.Unsupervised
{
    public class HClusterModel<T>
    {
        public TypeDescription Description { get; set; }
        public ILinker Linker { get; set; }

        public Cluster<T> Generate(IEnumerable<T> examples, ILinker linker)
        {
            // Initialize
            Linker = linker;

            var clusters = new List<Cluster<T>>();
            var distances = new Dictionary<Tuple<int, int>, double>();

            // Load data 
            var ie = examples.ToArray();
            if (Description == null)
                Description = Converter.GetDescription(typeof(T)).BuildDictionaries<T>(ie);


            Matrix X = Converter.Convert<T>(ie, Description.Features);

            // Create a new cluster for each data point

            for (int i = 0; i < X.Rows; i++)
                clusters.Add(new Cluster<T> { Id = i, 
                                              Points = new Vector[] { X[i, VectorType.Row] }, 
                                              Members = new T[] { ie[i] } });

            // Set the current closest distance/pair to the first pair of clusters
            var key = new Tuple<int, int>(0, 0);
            var distance = 0.0;

            var clusterId = X.Rows;

            while (clusters.Count > 1)
            {
                var closestClusters = new Tuple<int, int>(0, 1);
                var smallestDistance = Linker.Distance(clusters[0].Points, clusters[1].Points);

                // Loop through each of the clusters looking for the two closest

                //Parallel.For(0, clusters.Count, i =>
                for (int i = 0; i < clusters.Count; i++)
                {
                    for (int j = i + 1; j < clusters.Count; j++)
                    {
                        key = new Tuple<int, int>(clusters[i].Id, clusters[j].Id);

                        // Cache the distance if it hasn't been calculated yet
                        if (!distances.ContainsKey(key))
                            distances.Add(key, Linker.Distance(clusters[i].Points, clusters[j].Points));

                        // Update closest clusters and distance if necessary
                        distance = distances[key];

                        //distance = Linker.Distance(clusters[i].Points, clusters[j].Points);

                        if (distance < smallestDistance)
                        {
                            smallestDistance = distance;
                            closestClusters = new Tuple<int, int>(i, j);
                        }
                    }
                }

                // does this matter??
                var min = System.Math.Min(closestClusters.Item1, closestClusters.Item2);
                var max = System.Math.Max(closestClusters.Item1, closestClusters.Item2);

                var newCluster = new Cluster<T>(clusterId, clusters[min], clusters[max]);

                // Remove the merged clusters
                clusters.RemoveAt(min);
                clusters.RemoveAt(max - 1);

                // Add new cluster
                clusters.Add(newCluster);
                clusterId++;
            }

            return clusters.Single();
        }
    }
}
